<?php

class Customer extends CActiveRecord
{
	/**
	 * The followings are the available columns in table 'YiiShopCustomer':
	 * @var integer $customer_id
	 * @var integer $userid
	 * @var string $address
	 * @var string $zipcode
	 * @var string $city
	 * @var string $country
	 * @var string $email
	 */

	/**
	 * Returns the static model of the specified AR class.
	 * @return CActiveRecord the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'YiiShopCustomer';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('customer_id', 'required'),
			array('customer_id, userid', 'numerical', 'integerOnly'=>true),
			array('address, zipcode, city, country, email', 'length', 'max'=>45),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('customer_id, userid, address, zipcode, city, country, email', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'yiiShopOrders' => array(self::HAS_MANY, 'YiiShopOrder', 'customer_id'),
			'yiiShopShoppingCarts' => array(self::HAS_MANY, 'YiiShopShoppingCart', 'customer_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'customer_id' => 'Customer',
			'userid' => 'Userid',
			'address' => 'Address',
			'zipcode' => 'Zipcode',
			'city' => 'City',
			'country' => 'Country',
			'email' => 'Email',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('customer_id',$this->customer_id);

		$criteria->compare('userid',$this->userid);

		$criteria->compare('address',$this->address,true);

		$criteria->compare('zipcode',$this->zipcode,true);

		$criteria->compare('city',$this->city,true);

		$criteria->compare('country',$this->country,true);

		$criteria->compare('email',$this->email,true);

		return new CActiveDataProvider('Customer', array(
			'criteria'=>$criteria,
		));
	}
}