<?php

class Order extends CActiveRecord
{
	/**
	 * The followings are the available columns in table 'YiiShopOrder':
	 * @var integer $order_id
	 * @var integer $customer_id
	 * @var string $ordering_date
	 * @var integer $ordering_done
	 * @var integer $ordering_confirmed
	 */

	/**
	 * Returns the static model of the specified AR class.
	 * @return CActiveRecord the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'YiiShopOrder';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('customer_id, ordering_date', 'required'),
			array('customer_id, ordering_done, ordering_confirmed', 'numerical', 'integerOnly'=>true),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('order_id, customer_id, ordering_date, ordering_done, ordering_confirmed', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'Customer' => array(self::BELONGS_TO, 'Customer', 'customer_id'),
			'Products' => array(self::MANY_MANY, 'Products', 'YiiShopProductOrder(order_id, product_id)'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'order_id' => 'Order',
			'customer_id' => 'Customer',
			'ordering_date' => 'Ordering Date',
			'ordering_done' => 'Ordering Done',
			'ordering_confirmed' => 'Ordering Confirmed',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('order_id',$this->order_id);

		$criteria->compare('customer_id',$this->customer_id);

		$criteria->compare('ordering_date',$this->ordering_date,true);

		$criteria->compare('ordering_done',$this->ordering_done);

		$criteria->compare('ordering_confirmed',$this->ordering_confirmed);

		return new CActiveDataProvider('Order', array(
			'criteria'=>$criteria,
		));
	}
}
