<?php

class Products extends CActiveRecord
{
	/**
	 * The followings are the available columns in table 'YiiShopProducts':
	 * @var integer $product_id
	 * @var string $title
	 * @var string $description
	 * @var string $price
	 * @var string $color
	 * @var string $weight
	 * @var string $material
	 * @var string $size
	 * @var string $unit
	 * @var integer $category_id
	 */

	/**
	 * Returns the static model of the specified AR class.
	 * @return CActiveRecord the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'YiiShopProducts';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('title, category_id', 'required'),
			array('product_id, category_id', 'numerical', 'integerOnly'=>true),
			array('title, price, color, weight, material, size, unit', 'length', 'max'=>45),
			array('description', 'safe'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('product_id, title, description, price, color, weight, material, size, unit, category_id', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'Orders' => array(self::MANY_MANY, 'Order', 'YiiShopProductOrder(order_id, product_id)'),
			'Category' => array(self::BELONGS_TO, 'Category', 'category_id'),
			'Images' => array(self::HAS_MANY, 'Image', 'product_id'),
			'ShoppingCarts' => array(self::HAS_MANY, 'ShoppingCart', 'product_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'product_id' => 'Product',
			'title' => 'Title',
			'description' => 'Description',
			'price' => 'Price',
			'color' => 'Color',
			'weight' => 'Weight',
			'material' => 'Material',
			'size' => 'Size',
			'unit' => 'Unit',
			'category_id' => 'Category',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('product_id',$this->product_id);

		$criteria->compare('title',$this->title,true);

		$criteria->compare('description',$this->description,true);

		$criteria->compare('price',$this->price,true);

		$criteria->compare('color',$this->color,true);

		$criteria->compare('weight',$this->weight,true);

		$criteria->compare('material',$this->material,true);

		$criteria->compare('size',$this->size,true);

		$criteria->compare('unit',$this->unit,true);

		$criteria->compare('category_id',$this->category_id);

		return new CActiveDataProvider('Products', array(
			'criteria'=>$criteria,
		));
	}
}
